@@ -13,7 +13,7 @@
 #include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kbuttonbox.h>
 #include <kcolorbutton.h>
 #include "gravity.h"
@@ -27,6 +27,7 @@
 #include <qspinbox.h>
 #include <kstandarddirs.h>
 #include <math.h>
+#include <kmessagebox.h>
 // libkscreensaver interface
 extern "C"
 {
@@ -60,6 +61,7 @@ KGravitySetup::KGravitySetup( QWidget *parent, const char *name )
 ;
 	connect( PushButton1, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 	connect( PushButton2, SIGNAL( clicked() ), SLOT( reject() ) );
+	connect( PushButton3, SIGNAL( clicked() ), SLOT( aboutPressed() ) );
 	connect(  SpinBox1, SIGNAL( valueChanged(int)), saver, SLOT( updateSize(int)));
 	connect( RadioButton1, SIGNAL( toggled(bool)), saver, SLOT( doStars(bool)));
 
@@ -112,7 +114,8 @@ void KGravitySetup::slotOkPressed()
 
 void KGravitySetup::aboutPressed()
 {
-
+    KMessageBox::about(this,
+        i18n("<h3>Gravity</h3>\n<p>Particle Gravity Screen Saver for KDE</p>\nCopyright (c)  Ian Reinhart Geiser 2001<br>\n\n<p>KConfig code and KScreenSaver \"Setup...\" improvements by Nick Betcher <nbetcher@usinternet.com> 2001</p>"));
 }
 //-----------------------------------------------------------------------------
 
@@ -282,7 +285,7 @@ void Gravity::resizeGL ( int width, int height )
 	glLoadIdentity();						// Reset The Projection Matrix
 
 	// Calculate The Aspect Ratio Of The Window
-	gluPerspective(45.0f,(GLfloat)width/(GLfloat)height,0.10f,100.0f);
+	gluPerspective(45.0f,(GLfloat)width/(GLfloat)height,0.1f,100.0f);
 
 	glMatrixMode(GL_MODELVIEW);					// Select The Modelview Matrix
 	glLoadIdentity();
@@ -295,10 +298,14 @@ void Gravity::paintGL ()
 	glLoadIdentity();
 						// Reset The ModelView Matrix
 	transIndex++;
-	//glRotatef(transIndex/180, 1,0,0);
-	//glRotatef(transIndex/180, 0,1,0);
-	//glRotatef(transIndex/180, 0,0,1);
-	glTranslatef( GLfloat(5.0*sin(3.14*transIndex/3600)), GLfloat(4.0*cos(3.14*transIndex/3600)), 0.0 );
+	//glRotatef(transIndex, 1,0,0);
+	//glRotatef(transIndex, 0,1,0);
+	//glRotatef(transIndex, 0,0,1);
+	float xmax = 10.0;
+	float ymax = 15.0;
+	glTranslatef( GLfloat(xmax*sin(3.14*transIndex/360)-xmax),
+			GLfloat(ymax*cos(3.14*transIndex/360)-ymax),
+			0.0 );
 	for (loop=0;loop<MAX_PARTICLES;loop++)				// Loop Through All The Particles
 	{
 		if (particle[loop].active)				// If The Particle Is Active
@@ -335,9 +342,9 @@ void Gravity::paintGL ()
 			glTexCoord2d( 0, 0 );
 			glVertex3f( x - particle[loop].size, y - particle[loop].size, z );
 		glEnd( );
-			particle[loop].x=(particle[loop].xo*sin(particle[loop].index))*pow(particle[loop].index/particle[loop].indexo,8.0);
-			particle[loop].y=(particle[loop].yo*cos(particle[loop].index))*pow(particle[loop].index/particle[loop].indexo,8.0);
-			particle[loop].z=(particle[loop].zo*sin(particle[loop].index))*pow(particle[loop].index/particle[loop].indexo,8.0);
+			particle[loop].x=(particle[loop].xo*sin(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
+			particle[loop].y=(particle[loop].yo*cos(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
+			particle[loop].z=(particle[loop].zo*sin(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
 			particle[loop].index-=0.05;
 			if (particle[loop].index<0.0f )			// If Particle Is Burned Out
 			{
@@ -347,7 +354,6 @@ void Gravity::paintGL ()
 		}
 	}
 
-	swapBuffers ();
 	glFlush();
 }
 void Gravity::setSize( float newSize )
@@ -384,10 +390,13 @@ void Gravity::buildParticle(int loop)
 	particle[loop].b=colors[col][2];			// Select Blue From Color Table
 	particle[loop].size=size;
 	particle[loop].x = float(rand()%100-50)*4.0;
-	particle[loop].y = float(rand()%100-50)*4.0;
+	particle[loop].y = float(rand()%20-10)*4.0;
 	particle[loop].z = float(rand()%100-50)*4.0;
 	particle[loop].xo = particle[loop].x;
-	particle[loop].yo = particle[loop].y;
+	if ((1+(rand() % 10) > 5))
+		particle[loop].yo = particle[loop].y;
+	else
+		particle[loop].yo = 0.0;
 	particle[loop].zo = particle[loop].z;
 
 }
