@@ -45,7 +45,7 @@
 
 #include <kapplication.h>
 #include <kbuttonbox.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kglobal.h>
@@ -295,7 +295,7 @@ kVmSetup::kVmSetup( QWidget *parent, const char *name )
 	QVBoxLayout *tl11 = new QVBoxLayout(5);
 	tl1->addLayout(tl11);	
 
-	label = new QLabel( i18n("Virtual machine speed"), this );
+	label = new QLabel( i18n("Virtual machine speed:"), this );
 	tl11->addWidget(label);
 
 	slider = new QSlider( QSlider::Horizontal, this );
@@ -308,7 +308,7 @@ kVmSetup::kVmSetup( QWidget *parent, const char *name )
 	tl11->addWidget(slider);
 	tl11->addStretch(1);
 
-	label = new QLabel( i18n("Display update speed"), this );
+	label = new QLabel( i18n("Display update speed:"), this );
 	tl11->addWidget(label);
 
 	slider = new QSlider( QSlider::Horizontal, this );
@@ -333,14 +333,14 @@ kVmSetup::kVmSetup( QWidget *parent, const char *name )
 	tl1->addWidget(frame);
 
 	KButtonBox *bbox = new KButtonBox(this);	
-	button = bbox->addButton( i18n("About"));
+	button = bbox->addButton( i18n("&About"));
 	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
 	bbox->addStretch(1);
 
-	button = bbox->addButton( i18n("OK"));	
+	button = bbox->addButton( i18n("&OK"));	
 	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
-	button = bbox->addButton(i18n("Cancel"));
+	button = bbox->addButton(i18n("&Cancel"));
 	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
 	bbox->layout();
 	tl->addWidget(bbox);
@@ -397,7 +397,7 @@ void kVmSetup::slotAbout()
 {
 	KMessageBox::about(this,
 		i18n("Virtual Machine Version 0.1\n\nCopyright (c) 2000 Artur Rataj <art@zeus.polsl.gliwice.pl>\n"),
-	        i18n("About The Virtual Machine")
+	        i18n("About Virtual Machine")
 	);
 }
 
