@@ -27,6 +27,7 @@
 #include <kimageio.h>
 #include <kfiledialog.h>
 #include <kstandarddirs.h>
+#include <kurlrequester.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -92,6 +93,7 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
 //----------------------------------------------------------------------------
 kSlideShowSaver::~kSlideShowSaver()
 {
+  delete [] mIntArray;
   mTimer.stop();
   if (mPainter.isActive()) mPainter.end();
   QColor::leaveAllocContext();
@@ -277,7 +279,7 @@ int kSlideShowSaver::effectMeltdown(bool aInit)
 
   if (aInit)
   {
-    if (mIntArray) delete mIntArray;
+    delete [] mIntArray;
     mw = width();
     mh = height();
     mdx = 4;
@@ -302,7 +304,7 @@ int kSlideShowSaver::effectMeltdown(bool aInit)
 
   if (done)
   {
-    delete mIntArray;
+    delete [] mIntArray;
     mIntArray = NULL;
     return -1;
   }
@@ -904,24 +906,23 @@ kSlideShowSetup::kSlideShowSetup(QWidget *aParent, const char *aName):
   mSaver = new kSlideShowSaver(mPreview->winId());
   tl1->addWidget(mPreview);
 
-  mCboDir = new QComboBox(false, this);
-  mCboDir->insertItem(i18n("Select..."));
-  mCboDir->setMaxCount(21);
-  mCboDir->setSizeLimit(20);
-  mCboDir->setMaximumWidth(32767);
-  connect(mCboDir, SIGNAL(activated(int)), SLOT(slotDirSelected(int)));
-  tl->addWidget(mCboDir);
+	
+	mDirChooser = new KURLRequester(this);
+	mDirChooser->setMode(KFile::Directory | KFile::ExistingOnly);
+  connect(mDirChooser, SIGNAL(returnPressed(const QString &)), SLOT(slotDirSelected(const QString &)));
+  connect(mDirChooser, SIGNAL(urlSelected(const QString &)), SLOT(slotDirSelected(const QString &)));
+  tl->addWidget(mDirChooser);
   //  tl->addSpacing(5);
 
   KButtonBox *bbox = new KButtonBox(this);
-  button = bbox->addButton(i18n("About"));
+  button = bbox->addButton(i18n("&About"));
   connect(button, SIGNAL(clicked()), SLOT(slotAbout()));
   bbox->addStretch(1);
 
-  button = bbox->addButton(i18n("OK"));
+  button = bbox->addButton(i18n("&OK"));
   connect(button, SIGNAL(clicked()), SLOT(slotOkPressed()));
 
-  button = bbox->addButton(i18n("Cancel"));
+  button = bbox->addButton(i18n("&Cancel"));
   connect(button, SIGNAL(clicked()), SLOT(reject()));
   bbox->layout();
   tl->addWidget(bbox);
@@ -935,8 +936,8 @@ kSlideShowSetup::kSlideShowSetup(QWidget *aParent, const char *aName):
 //-----------------------------------------------------------------------------
 void kSlideShowSetup::readSettings()
 {
-  int i, num, cur;
-  QString key, value, curDir;
+  int num;
+  QString dirname;
   KConfig *config = KGlobal::config();
 
   config->setGroup("Settings");
@@ -949,34 +950,15 @@ void kSlideShowSetup::readSettings()
   QString str = i18n("Delay: %1 seconds").arg(num);
   mLblDelay->setText(str);
 
-  curDir = config->readEntry("Directory");
+  dirname = config->readEntry("Directory");
 
-  config->setGroup("Slide Show");
-  num = config->readNumEntry("Count", 0);
-  for (i=0, cur=-1; i<num; i++)
-  {
-    key = QString::fromLatin1("Dir%1").arg(i);
-    value = config->readEntry(key);
-    if (!value.isEmpty())
-    {
-      if (cur < 0 && value == curDir) cur = i;
-      mCboDir->insertItem(value);
-    }
-  }
-  if (cur < 0 && !curDir.isEmpty())
-  {
-    mCboDir->insertItem(curDir);
-    mCboDir->setCurrentItem(mCboDir->count());
-  }
-  else mCboDir->setCurrentItem(cur+1);
+	mDirChooser->setURL(dirname);
 }
 
 
 //-----------------------------------------------------------------------------
 void kSlideShowSetup::writeSettings()
 {
-  int i, num;
-  QString key, value;
   KConfig *config = KGlobal::config();
 
   config->setGroup("Settings");
@@ -985,21 +967,7 @@ void kSlideShowSetup::writeSettings()
   config->writeEntry("PrintName",  mCbxShowName->isChecked());
   config->writeEntry("Delay", mDelay->value());
 
-  if (mCboDir->currentItem() >= 1)
-    config->writeEntry("Directory", mCboDir->currentText());
-
-  config->setGroup("Slide Show");
-
-  num = mCboDir->count() - 1;
-  if (num > 20) num = 20;
-  config->writeEntry("Count", num);
-
-  for (i=0; i<num; i++)
-  {
-    key = QString::fromLatin1("Dir%1").arg(i);
-    value = mCboDir->text(i+1);
-    config->writeEntry(key, value);
-  }
+  config->writeEntry("Directory", mDirChooser->url());
 
   config->sync();
 
@@ -1022,17 +990,8 @@ void kSlideShowSetup::slotDelay(int x)
 
 
 //-----------------------------------------------------------------------------
-void kSlideShowSetup::slotDirSelected(int aIdx)
+void kSlideShowSetup::slotDirSelected(const QString &)
 {
-  if (aIdx <= 0)
-  {
-    QString dirName;
-    dirName = KFileDialog::getExistingDirectory(QDir::homeDirPath(), this,
-		   i18n("Choose Images Directory") );
-    if (dirName.isEmpty()) return;
-    mCboDir->insertItem(dirName, 1);
-    mCboDir->setCurrentItem(1);
-  }
   writeSettings();
 }
 
