@@ -22,6 +22,8 @@
 */
 // layout management added 1998/04/19 by Mario Weilguni <mweilguni@kde.org>
 
+#include <config.h>		/* platform dependent defines by KDE */
+
 #include <qslider.h>
 #include <kglobal.h>
 #include <kconfig.h>
@@ -37,7 +39,9 @@
 				   * erase the whole window than to erase each star
 				 */
 
-#if HAVE_GETTIMEOFDAY
+#if !defined(HAVE_GETTIMEOFDAY)
+#define ADAPT_ERASE  0
+#else
 #define ADAPT_ERASE  1		/* If 1, then we try ADAPT_CHECKS black XFillArcs,
 				   * and after, ADAPT_CHECKS XFillRectangle.
 				   * We check which method seems better, knowing that
@@ -49,18 +53,19 @@
 				   * have to use another function for others ?
 				   * This value overrides USEOLDXARCS.
 				 */
+#define GETTIMEOFDAY(tv) gettimeofday(tv, NULL)
 
-#ifdef USE_XVMSUTILS
+#if defined(USE_XVMSUTILS)
 #if 0
 #include "../xvmsutils/unix_time.h"
 #else
 #include <X11/unix_time.h>
 #endif
 #endif
-#if HAVE_SYS_TIME_H
+#if defined(HAVE_SYS_TIME_H)
 #include <sys/time.h>
 #else
-#if HAVE_SYS_SELECT_H
+#if defined(HAVE_SYS_SELECT_H)
 #include <sys/select.h>
 #endif
 #endif
@@ -962,7 +967,7 @@ void kBoubouleSaver::readSettings()
 	numPoints = config->readNumEntry( "NumPoints", DEFPOINTS );
 	pointSize = config->readNumEntry( "PointSize", DEFSIZE );
 	colorCycleDelay = config->readNumEntry( "ColorCycleDelay", DEFCCSPEED );
-	flag_3dmode = config->readBoolEntry( "3DMode", false );
+	flag_3dmode = config->readBoolEntry( "3DMode", true );
 
 	delete config;
 }
@@ -1065,14 +1070,14 @@ kBoubouleSetup::kBoubouleSetup( QWidget *parent, const char *name )
 	tl1->addWidget(preview);
 
 	KButtonBox *bbox = new KButtonBox(this);	
-	button = bbox->addButton( i18n("About"));
+	button = bbox->addButton( i18n("&About"));
 	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
 	bbox->addStretch(1);
 
-	button = bbox->addButton( i18n("OK"));	
+	button = bbox->addButton( i18n("&OK"));	
 	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
-	button = bbox->addButton(i18n("Cancel"));
+	button = bbox->addButton(i18n("&Cancel"));
 	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
 	bbox->layout();
 	tl->addWidget(bbox);
@@ -1094,7 +1099,7 @@ void kBoubouleSetup::readSettings()
 	numPoints = config->readNumEntry( "NumPoints", DEFPOINTS );
 	pointSize = config->readNumEntry( "PointSize", DEFSIZE );
 	colorCycleDelay = config->readNumEntry( "ColorCycleDelay", DEFSIZE );
-	flag_3dmode = config->readBoolEntry( "3DMode", false );
+	flag_3dmode = config->readBoolEntry( "3DMode", true );
 
 	delete config;
 }
