@@ -1058,7 +1058,7 @@ kMorph3dSetup::kMorph3dSetup( QWidget *parent, const char *name )
     slider->setTickInterval(10);
     connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
 
-    label = new QLabel( i18n("Object Type:"), page );
+    label = new QLabel( i18n("Object type:"), page );
     vb->addWidget( label );
 
     slider = new QSlider(MINBATCH, MAXBATCH, 1, maxLevels,
