@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.cpp,v 1.3 2002/03/12 01:17:49 fredrik Exp $
+ *	$Id: cdeclient.cpp,v 1.11 2002/08/29 08:59:31 lunakl Exp $
  *	
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -28,6 +28,8 @@
 
 using namespace KWinInternal;
 
+namespace CDE {
+
 static int s_frameWidth = 5;
 static bool titlebarButtonMode = true;
 static bool coloredFrame = true;
@@ -162,8 +164,8 @@ CdeClient::CdeClient( Workspace* ws, WId w, QWidget* parent, const char* name )
     setBackgroundMode( QWidget::NoBackground );
 
     mainLayout = new QVBoxLayout( this );
-    QHBoxLayout* windowLayout = new QHBoxLayout();
-    titleLayout = new QHBoxLayout();
+    QBoxLayout* windowLayout = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
+    titleLayout = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
 
     if ( s_frameWidth > 1 )
     {
@@ -245,7 +247,7 @@ void CdeClient::addClientButtons( const QString& s )
 
                 // Close button
                 case 'X':
-                    if ( !button[BtnClose] )
+                    if ( !button[BtnClose] && isCloseable())
                     {
                         button[BtnClose] = new CdeButton(this, "close", BtnClose, i18n("Close"));
                         connect( button[BtnClose], SIGNAL( clicked()), SLOT(closeWindow()) );
@@ -279,23 +281,22 @@ void CdeClient::maximizeChange(bool m)
 
 void CdeClient::menuButtonPressed()
 {
-    static QTime* t = 0;
-    static CdeClient* tc = 0;
-    if ( !t )
+    static QTime* t = NULL;
+    static CdeClient* lastClient = NULL;
+    if( t == NULL )
 	t = new QTime;
-
-    if ( tc != this || t->elapsed() > QApplication::doubleClickInterval() )
+    bool dbl = ( lastClient == this && t->elapsed() <= QApplication::doubleClickInterval());
+    lastClient = this;
+    t->start();
+    if( !dbl )
     {
-	workspace()->clientPopup( this )->popup(
-	button[BtnMenu]->mapToGlobal(
-	button[BtnMenu]->rect().bottomLeft() ) );
-	button[BtnMenu]->animateClick();
+        QPoint pos = button[BtnMenu]->mapToGlobal(
+    	    button[BtnMenu]->rect().bottomLeft() );
+	workspace()->showWindowMenu( pos.x(), pos.y(), this );
+	button[BtnMenu]->setDown(false);
     }
     else
 	closeWindow();
-
-    t->start();
-    tc = this;
 }
 
 void CdeClient::resizeEvent( QResizeEvent* e)
@@ -604,19 +605,21 @@ static void readConfig()
     if (s_frameWidth > 10) s_frameWidth = 10;
 }
 
+};
+
 extern "C"
 {
     Client* allocate( Workspace* ws, WId w )
     {
-        return ( new CdeClient(ws, w) );
+        return ( new CDE::CdeClient(ws, w) );
     }
     void init()
     {
-	readConfig();
+        CDE::readConfig();
     }
     void reset()
     {
-        readConfig();
+        CDE::readConfig();
 	
 	// Tell kwin to reset all the clients
         Workspace::self()->slotResetAllClientsDelayed();
