@@ -33,12 +33,12 @@ CdeConfig::CdeConfig( KConfig* conf, QWidget* parent )
 	widthSlider->setTickmarks( QSlider::Below );
 	QWhatsThis::add( widthSlider, i18n("By moving this slider back and forth, you can adjust the width of the "
 					    "window frame to a value of your liking.\n"
-					    "Note: If you move the slider to it's leftmost position, the window frames "
+					    "Note: If you move the slider to its leftmost position, the window frames "
 					    "will be turned off, which means that you won't be able to resize windows "
 					    "by clicking and dragging their borders.") );
 	QHBox *hbox = new QHBox( gbSlider );
 	hbox->setSpacing( 6 );
-	QLabel *label1 = new QLabel( i18n("Thin"), hbox );
+	new QLabel( i18n("Thin"), hbox );
 	QLabel *label2 = new QLabel( i18n("Medium"), hbox );
 	label2->setAlignment( AlignCenter );
 	QLabel *label3 = new QLabel( i18n("Wide"), hbox );
@@ -47,10 +47,10 @@ CdeConfig::CdeConfig( KConfig* conf, QWidget* parent )
 	bgAlign = new QButtonGroup( 3, Qt::Horizontal, i18n("Text &Alignment"), groupBox );
 	bgAlign->setExclusive( true );
 	QWhatsThis::add( bgAlign, i18n("Use these buttons to set the alignment of the titlebar caption text.") );
-	QRadioButton *radio1 = new QRadioButton( i18n("Left"), bgAlign, "AlignLeft" );
+	new QRadioButton( i18n("Left"), bgAlign, "AlignLeft" );
 	QRadioButton *radio2 = new QRadioButton( i18n("Centered"), bgAlign, "AlignHCenter" );
 	radio2->setChecked( true );
-	QRadioButton *radio3 = new QRadioButton( i18n("Right"), bgAlign, "AlignRight" );
+	new QRadioButton( i18n("Right"), bgAlign, "AlignRight" );
 	
 	cbColorBorder = new QCheckBox( i18n("Draw window frames using &titlebar colors"), groupBox );
 	QWhatsThis::add( cbColorBorder, i18n("When selected, the window decoration borders "
@@ -100,7 +100,7 @@ void CdeConfig::slotSelectionChanged( int )
 
 // Loads the configurable options from the kwinrc config file
 // It is passed the open config from kwindecoration to improve efficiency
-void CdeConfig::load( KConfig* conf )
+void CdeConfig::load( KConfig* /*conf*/ )
 {
 	cdeConfig->setGroup("General");
 
@@ -121,7 +121,7 @@ void CdeConfig::load( KConfig* conf )
 
 
 // Saves the configurable options to the kwinrc config file
-void CdeConfig::save( KConfig* conf )
+void CdeConfig::save( KConfig* /*conf*/ )
 {
 	cdeConfig->setGroup("General");
 	cdeConfig->writeEntry( "FrameWidth", widthSlider->value() );
