@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Sep 6 2001
     copyright            : (C) 2001 by Henning Burchardt
-    email                : h_burchardt@gmx.de
+    email                : h_burchardt@gmx.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,13 +15,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <cmath>
 #include <qpixmap.h>
 #include <qbitmap.h>
 #include <qpainter.h>
 #include <qapplication.h>
 #include <qlayout.h>
-#include <qfontmetrics.h>
 #include <klocale.h>
 #include <kpixmapeffect.h>
 #include <kpixmap.h>
@@ -32,16 +30,20 @@
 #include "glowclient.h"
 #include "glowbutton.h"
 
-#define SIDE_MARGIN 4
-#define BOTTOM_MARGIN 2
-#define RESIZE_HANDLE_WIDTH 20
-#define RESIZE_HANDLE_HEIGHT 7
-#define TITLE_MARGIN 2
-#define TITLE_SPACING 1
-#define TITLE_BAR_EXTENSION_SIZE 20
 
 using namespace KWinInternal;
 
+
+namespace Glow
+{
+
+static const int SIDE_MARGIN = 4;
+static const int BOTTOM_MARGIN = 2;
+static const int TITLE_MARGIN = 2;
+static const int TITLE_SPACING = 1;
+static const int RESIZE_HANDLE_WIDTH = 20;
+static const int RESIZE_HANDLE_HEIGHT = 3;
+
 //-----------------------------------------------------------------------------
 
 GlowClientConfig::GlowClientConfig()
@@ -53,58 +55,24 @@ void GlowClientConfig::load()
 	KConfig conf("kwinglowrc");
 	conf.setGroup("General");
 
-	QColor defaultButtonColor = Qt::white;
-	QColor defaultCloseButtonColor = Qt::red;
+	const QColor defaultButtonColor(DEFAULT_BUTTON_COLOR);
+	const QColor defaultCloseButtonColor(DEFAULT_CLOSE_BUTTON_COLOR);
 
-	QString stickyButtonGlowType =
-		conf.readEntry("stickyButtonGlowType", "TitleBar");
-	if(stickyButtonGlowType=="TitleBar")
-		stickyButtonGlowColor = options->color(Options::TitleBar);
-	else if(stickyButtonGlowType=="TitleBlend")
-		stickyButtonGlowColor = options->color(Options::TitleBlend);
-	else // if( stickyButtonGlowType=="Custom" )
-		stickyButtonGlowColor = conf.readColorEntry(
-			"stickyButtonGlowColor", &defaultButtonColor);
 
-	QString helpButtonGlowType =
-		conf.readEntry("helpButtonGlowType", "TitleBar");
-	if(helpButtonGlowType=="TitleBar")
-		helpButtonGlowColor = options->color(Options::TitleBar);
-	else if(helpButtonGlowType=="TitleBlend")
-		helpButtonGlowColor = options->color(Options::TitleBlend);
-	else // if( helpButtonGlowType=="Custom" )
-		helpButtonGlowColor = conf.readColorEntry(
-			"helpButtonGlowColor", &defaultButtonColor);
+	stickyButtonGlowColor = conf.readColorEntry(
+		"stickyButtonGlowColor", &defaultButtonColor);
 
-	QString iconifyButtonGlowType =
-		conf.readEntry("iconifyButtonGlowType", "TitleBar");
-	if(iconifyButtonGlowType=="TitleBar")
-		iconifyButtonGlowColor = options->color(Options::TitleBar);
-	else if(iconifyButtonGlowType=="TitleBlend")
-		iconifyButtonGlowColor = options->color(Options::TitleBlend);
-	else // if( iconifyButtonGlowType=="Custom" )
-		iconifyButtonGlowColor = conf.readColorEntry(
-			"iconifyButtonGlowColor", &defaultButtonColor);
+	helpButtonGlowColor = conf.readColorEntry(
+		"helpButtonGlowColor", &defaultButtonColor);
 
-	QString maximizeButtonGlowType =
-		conf.readEntry("maximizeButtonGlowType", "TitleBar");
-	if(maximizeButtonGlowType=="TitleBar")
-		maximizeButtonGlowColor = options->color(Options::TitleBar);
-	else if(maximizeButtonGlowType=="TitleBlend")
-		maximizeButtonGlowColor = options->color(Options::TitleBlend);
-	else // if( maximizeButtonGlowType=="Custom" )
-		maximizeButtonGlowColor = conf.readColorEntry(
-			"maximizeButtonGlowColor", &defaultButtonColor);
+	iconifyButtonGlowColor = conf.readColorEntry(
+		"iconifyButtonGlowColor", &defaultButtonColor);
 
-	QString closeButtonGlowType =
-		conf.readEntry("closeButtonGlowType", "Custom");
-	if(closeButtonGlowType=="TitleBar")
-		closeButtonGlowColor = options->color(Options::TitleBar);
-	else if(closeButtonGlowType=="TitleBlend")
-		closeButtonGlowColor = options->color(Options::TitleBlend);
-	else // if( closeButtonGlowType=="Custom" )
-		closeButtonGlowColor = conf.readColorEntry(
-			"closeButtonGlowColor", &defaultCloseButtonColor);
+	maximizeButtonGlowColor = conf.readColorEntry(
+		"maximizeButtonGlowColor", &defaultButtonColor);
+
+	closeButtonGlowColor = conf.readColorEntry(
+		"closeButtonGlowColor", &defaultCloseButtonColor);
 
 	showResizeHandle = conf.readBoolEntry("showResizeHandle", true);
 	titlebarGradientType = conf.readNumEntry("titlebarGradientType",
@@ -128,10 +96,10 @@ GlowClientGlobals::~GlowClientGlobals()
 	m_instance = 0;
 }
 
-QString GlowClientGlobals::getPixmapName(
-	int type, bool isActive, bool isLeft, bool isSmall)
+QString GlowClientGlobals::getPixmapName(PixmapType type, 
+		bool isActive, bool isLeft, bool isSmall)
 {
-	QString s = getPixmapTypeName(type);
+	QString s = getPixmapTypeName(static_cast<PixmapType>(type));
 	s += "|";
 	s += isActive ? "Active" : "NotActive";
 	s += "|";
@@ -155,20 +123,6 @@ void GlowClientGlobals::readConfig()
 	config->load();
 }
 
-std::vector<int> GlowClientGlobals::getPixmapTypes()
-{
-	std::vector<int> pixmapTypes;
-	pixmapTypes.push_back(StickyOn);
-	pixmapTypes.push_back(StickyOff);
-	pixmapTypes.push_back(Help);
-	pixmapTypes.push_back(Iconify);
-	pixmapTypes.push_back(MaximizeOn);
-	pixmapTypes.push_back(MaximizeOff);
-	pixmapTypes.push_back(Close);
-
-	return pixmapTypes;
-}
-
 void GlowClientGlobals::reset()
 {
 	deletePixmaps();
@@ -178,18 +132,16 @@ void GlowClientGlobals::reset()
 }
 
 void GlowClientGlobals::createPixmaps()
-{
-	std::vector<int> types = getPixmapTypes();
-	for( int i=0; i<types.size(); i++ )
-	{
-		createPixmap(types[i], false, false, false);
-		createPixmap(types[i], false, false, true);
-		createPixmap(types[i], false, true, false);
-		createPixmap(types[i], false, true, true);
-		createPixmap(types[i], true, false, false);
-		createPixmap(types[i], true, false, true);
-		createPixmap(types[i], true, true, false);
-		createPixmap(types[i], true, true, true);
+{	
+	for( int type=0; type<=Close; type++ ) {
+		createPixmap(static_cast<PixmapType>(type), false, false, false);
+		createPixmap(static_cast<PixmapType>(type), false, false, true);
+		createPixmap(static_cast<PixmapType>(type), false, true, false);
+		createPixmap(static_cast<PixmapType>(type), false, true, true);
+		createPixmap(static_cast<PixmapType>(type), true, false, false);
+		createPixmap(static_cast<PixmapType>(type), true, false, true);
+		createPixmap(static_cast<PixmapType>(type), true, true, false);
+		createPixmap(static_cast<PixmapType>(type), true, true, true);
 	}
 }
 
@@ -198,28 +150,30 @@ void GlowClientGlobals::deletePixmaps()
 	PixmapCache::clear();
 }
 
-QString GlowClientGlobals::getPixmapTypeName(int type)
+const QString GlowClientGlobals::getPixmapTypeName(PixmapType type)
 {
-	if( type == StickyOn )
-		return "StickyOn";
-	else if( type == StickyOff )
-		return "StickyOff";
-	else if( type == Help )
-		return "Help";
-	else if( type == Iconify )
-		return "Iconify";
-	else if( type == MaximizeOn )
-		return "MaximizeOn";
-	else if( type == MaximizeOff )
-		return "MaximizeOff";
-	else if( type == Close )
-		return "Close";
-	else
-		return QString::null;
+	switch(type) {
+		case (StickyOn):
+			return "StickyOn";
+		case(StickyOff ):
+			return "StickyOff";
+		case(Help):
+			return "Help";
+		case(Iconify):
+			return "Iconify";
+		case(MaximizeOn):
+			return "MaximizeOn";
+		case(MaximizeOff):
+			return "MaximizeOff";
+		case(Close):
+			return "Close";
+		default:
+			return QString::null;
+	}
 }
 
-void GlowClientGlobals::createPixmap(
-	int type, bool isActive, bool isLeft, bool isSmall)
+void GlowClientGlobals::createPixmap(PixmapType type, 
+		bool isActive, bool isLeft, bool isSmall)
 {
 	int size;
 	if( isSmall )
@@ -240,89 +194,83 @@ void GlowClientGlobals::createPixmap(
 	QPixmap pm(size, size);
 	pm.fill(c);
 
-	if( type == StickyOn )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, stickyon_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, stickyon_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->stickyButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
-	}
-	else if( type==StickyOff )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, stickyoff_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, stickyoff_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->stickyButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
-	}
-	else if( type==Help )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, help_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, help_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->helpButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
-	}
-	else if( type==Iconify )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, minimize_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, minimize_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->iconifyButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
-	}
-	else if( type==MaximizeOn )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, maximizeon_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, maximizeon_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->maximizeButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
-	}
-	else if( type==MaximizeOff )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, maximizeoff_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, maximizeoff_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->maximizeButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
-	}
-	else if( type==Close )
-	{
-		if( isSmall )
-			pm.setMask(QBitmap(size, size, close_small_bits, true));
-		else
-			pm.setMask(QBitmap(size, size, close_bits, true));
-		QPixmap *glowPm = buttonFactory->createGlowButtonPixmap(
-			QSize(size,size), config->closeButtonGlowColor, g, pm);
-		PixmapCache::insert(
-			getPixmapName(type, isActive, isLeft, isSmall), glowPm);
+	uchar *bits = 0; 
+	QColor buttonColor;
+	
+	switch(type) { 
+		case (StickyOn):
+		{
+			if( isSmall )
+				bits = stickyon_small_bits;
+			else
+				bits = stickyon_bits;
+			buttonColor = config->stickyButtonGlowColor;
+			break;
+		}
+		case (StickyOff):
+		{
+			if( isSmall )
+				bits = stickyoff_small_bits;
+			else
+				bits = stickyoff_bits;
+			buttonColor = config->stickyButtonGlowColor;
+			break;
+		}
+		case (Help):
+		{
+			if( isSmall )
+				bits = help_small_bits;
+			else
+				bits = help_bits;
+			buttonColor = config->helpButtonGlowColor;
+			break;
+		}
+		case (Iconify):
+		{
+			if( isSmall )
+				bits = minimize_small_bits;
+			else
+				bits = minimize_bits;
+			buttonColor = config->iconifyButtonGlowColor;
+			break;
+		}
+		case (MaximizeOn):
+		{
+			if( isSmall )
+				bits = maximizeon_small_bits;
+			else
+				bits = maximizeon_bits;
+			buttonColor = config->maximizeButtonGlowColor;
+			break;
+		}
+		case (MaximizeOff):
+		{
+			if( isSmall )
+				bits = maximizeoff_small_bits;
+			else
+				bits = maximizeoff_bits;
+			buttonColor = config->maximizeButtonGlowColor;
+			break;
+		}
+		case (Close):
+		{
+			if( isSmall )
+				bits = close_small_bits;
+			else
+				bits = close_bits;
+			buttonColor = config->closeButtonGlowColor;
+			break;
+		}
 	}
+
+	pm.setMask(QBitmap(size, size, bits, true));
+	QPixmap* glowPm = buttonFactory->createGlowButtonPixmap(QSize(size,size), buttonColor, g, pm);
+	PixmapCache::insert(getPixmapName(type, isActive, isLeft, isSmall), glowPm);
 }
 
 //-----------------------------------------------------------------------------
 
-GlowClient::GlowClient(KWinInternal::Workspace *ws, WId w,
-	QWidget *parent, const char* name )
+GlowClient::GlowClient(KWinInternal::Workspace *ws, WId w, QWidget *parent, const char* name )
 	: KWinInternal::Client(ws, w, parent, name),
 		m_stickyButton(0), m_helpButton(0), m_minimizeButton(0),
 		m_maximizeButton(0), m_closeButton(0),
@@ -351,15 +299,12 @@ void GlowClient::paintEvent( QPaintEvent *e )
 	GlowClientConfig *conf = GlowClientGlobals::instance()->config;
 	QRect r_this = rect();
 	QRect r_title = m_titleSpacer->geometry();
-	QRect r_wrapper = windowWrapper()->geometry();
-	QColorGroup titleCg =
-		options->colorGroup(Options::TitleBar, isActive());
-	QColorGroup titleBlendCg =
-		options->colorGroup(Options::TitleBlend, isActive());
+	QColorGroup titleCg = options->colorGroup(Options::TitleBar, isActive());
+	QColorGroup titleBlendCg = options->colorGroup(Options::TitleBlend, isActive());
 	QColorGroup cg = colorGroup();
 	QColor titleColor = options->color(Options::TitleBar, isActive());
 	QColor titleBlendColor = options->color(Options::TitleBlend, isActive());
-	QPainter painter;
+	QPainter p;
 	QPointArray pArray, pArray2;
 
 	// pixmap for title bar
@@ -368,14 +313,14 @@ void GlowClient::paintEvent( QPaintEvent *e )
 	KPixmapEffect::gradient(gradientPixmap, titleColor, titleBlendColor,
 		(KPixmapEffect::GradientType) conf->titlebarGradientType);
 	QPixmap titleBuffer(tBSize);
-	painter.begin(&titleBuffer);
-	painter.drawPixmap(2, 2, gradientPixmap);
+	p.begin(&titleBuffer);
+	p.drawPixmap(2, 2, gradientPixmap);
 	// draw caption
-	painter.setFont(options->font(isActive()));
-	painter.setPen(options->color(Options::Font, isActive()));
-	painter.drawText(r_title.x(), 0,
+	p.setFont(options->font(isActive()));
+	p.setPen(options->color(Options::Font, isActive()));
+	p.drawText(r_title.x(), 0,
 		r_title.width(), r_title.height(),
-		Qt::AlignLeft | Qt::AlignVCenter, caption() );
+		Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine, caption() );
 	// draw borders
 	pArray = QPointArray(7);
 	pArray.setPoint(0, 0, tBSize.height()-1);
@@ -386,52 +331,59 @@ void GlowClient::paintEvent( QPaintEvent *e )
 		tBSize.height()/2-1);
 	pArray.setPoint(5, r_title.x()+r_title.width()-1, tBSize.height()-1);
 	pArray.setPoint(6, 0, tBSize.height()-1);
-	painter.setPen(titleCg.mid());
-	painter.drawPolyline(pArray, 3, 4);
-	painter.setPen(Qt::black);
-	painter.drawPolyline(pArray, 0, 4);
-	painter.setPen(titleCg.light());
+	p.setPen(titleCg.mid());
+	p.drawPolyline(pArray, 3, 4);
+	p.setPen(Qt::black);
+	p.drawPolyline(pArray, 0, 4);
+	p.setPen(titleCg.light());
 	pArray2 = QPointArray(3);
 	pArray2.setPoint(0, 1, tBSize.height()-2);
 	pArray2.setPoint(1, 1, 1);
 	pArray2.setPoint(2, tBSize.width()-2, 1);
-	painter.drawPolyline(pArray2);
-	painter.end();
+	p.drawPolyline(pArray2);
+	p.end();
 
 	// set mask
 	QBitmap titleBitmap(tBSize);
 	titleBitmap.fill(Qt::color0);
-	painter.begin(&titleBitmap);
-	painter.setPen(Qt::color1);
-	painter.setBrush(Qt::color1);
-	painter.drawPolygon(pArray);
-	painter.end();
+	p.begin(&titleBitmap);
+	p.setPen(Qt::color1);
+	p.setBrush(Qt::color1);
+	p.drawPolygon(pArray);
+	p.end();
 	titleBuffer.setMask(titleBitmap);
 
-	painter.begin(this);
-	painter.drawPixmap(0, 0, titleBuffer);
-	painter.setPen(Qt::black);
-	painter.drawLine(0,tBSize.height(),0,r_this.height()-1);
-	painter.drawLine(0,r_this.height()-1,r_this.width()-1,r_this.height()-1);
-	painter.drawLine(r_this.width()-1,r_this.height()-1,
+	p.begin(this);
+	p.drawPixmap(0, 0, titleBuffer);
+	p.setPen(Qt::black);
+	p.drawLine(0,tBSize.height(),0,r_this.height()-1);
+	p.drawLine(0,r_this.height()-1,r_this.width()-1,r_this.height()-1);
+	p.drawLine(r_this.width()-1,r_this.height()-1,
 		r_this.width()-1,tBSize.height()/2);
-	painter.end();
+	p.end();
 
 	// paint resize handle if necessary
-	if( GlowClientGlobals::instance()->config->showResizeHandle
-		&& !isTool() && isResizable() )
+	if( conf->showResizeHandle && !isTool() && isResizable() )
 	{
-		int rh_w = RESIZE_HANDLE_WIDTH;
-		int rh_h = RESIZE_HANDLE_HEIGHT;
-		QSize rh_s(rh_w, rh_h);
+		QSize rh_s(RESIZE_HANDLE_WIDTH, RESIZE_HANDLE_HEIGHT);
 
-		QPixmap rh_pm = DrawUtils::drawRoundRectButton(rh_s,
-			options->colorGroup(Options::ButtonBg, isActive()));
-		painter.begin(this);
-		painter.drawPixmap(0,height()-rh_pm.height(),rh_pm);
-		painter.drawPixmap(width()-rh_pm.width(),height()-rh_pm.height(),
-			rh_pm);
-		painter.end();
+		KPixmap gradientPixmap1(rh_s);
+		KPixmapEffect::gradient(gradientPixmap1, titleBlendColor, titleColor,
+			KPixmapEffect::HorizontalGradient);
+		
+		KPixmap gradientPixmap2(rh_s);
+		KPixmapEffect::gradient(gradientPixmap2, titleColor, titleBlendColor,
+			KPixmapEffect::HorizontalGradient);
+
+		p.begin(this);
+		p.drawPixmap(1, height() - RESIZE_HANDLE_HEIGHT, gradientPixmap1);
+		p.drawPixmap(width() - RESIZE_HANDLE_WIDTH -1, height() - RESIZE_HANDLE_HEIGHT, gradientPixmap2);
+		p.setPen(titleColor);
+		p.drawLine(1, height() - RESIZE_HANDLE_HEIGHT, 
+						RESIZE_HANDLE_WIDTH, height()-RESIZE_HANDLE_HEIGHT);
+		p.drawLine(width() - RESIZE_HANDLE_WIDTH - 1, height() - RESIZE_HANDLE_HEIGHT, 
+						width() - 2, height() - RESIZE_HANDLE_HEIGHT);
+		p.end();
 	}
 }
 
@@ -449,11 +401,6 @@ void GlowClient::mouseDoubleClickEvent( QMouseEvent *e )
 			this, options->operationTitlebarDblClick());
 }
 
-void GlowClient::captionChange(const QString&)
-{
-	repaint(false);
-}
-
 void GlowClient::activeChange(bool)
 {
 	updateButtonPixmaps();
@@ -467,14 +414,13 @@ void GlowClient::iconChange()
 
 void GlowClient::stickyChange(bool on)
 {
-	if(on) {
+	if (on) {
 		m_stickyButton->setPixmapName(
 			GlowClientGlobals::instance()->getPixmapName(
 				GlowClientGlobals::StickyOn, isActive(),
 				isLeft(m_stickyButton), isTool()));
 		m_stickyButton->setTipText(i18n("Un-Sticky"));
-	}
-	else {
+	} else {
 		m_stickyButton->setPixmapName(
 			GlowClientGlobals::instance()->getPixmapName(
 				GlowClientGlobals::StickyOff, isActive(),
@@ -485,14 +431,13 @@ void GlowClient::stickyChange(bool on)
 
 void GlowClient::maximizeChange(bool on)
 {
-        if(on) {
+    if (on) {
 		m_maximizeButton->setPixmapName(
 			GlowClientGlobals::instance()->getPixmapName(
 				GlowClientGlobals::MaximizeOn, isActive(),
 				isLeft(m_maximizeButton), isTool()));
 		m_maximizeButton->setTipText(i18n("Restore"));
-	}
-	else {
+	} else {
 		m_maximizeButton->setPixmapName(
 			GlowClientGlobals::instance()->getPixmapName(
 				GlowClientGlobals::MaximizeOff, isActive(),
@@ -504,24 +449,21 @@ void GlowClient::maximizeChange(bool on)
 Client::MousePosition GlowClient::mousePosition(const QPoint &pos) const
 {
 	Client::MousePosition m = Nowhere;
-	int rh_w = RESIZE_HANDLE_WIDTH;
-	int rh_h = RESIZE_HANDLE_HEIGHT;
-
-	if( GlowClientGlobals::instance()->config->showResizeHandle && !isTool() )
-	{
-		if( pos.y() >= height()-rh_h )
-		{
-			if( pos.x() < rh_w )
+	if( GlowClientGlobals::instance()->config->showResizeHandle && !isTool() ) {
+		if( pos.y() >= height()-RESIZE_HANDLE_HEIGHT) {
+			if( pos.x() < RESIZE_HANDLE_WIDTH) {
 				m = BottomLeft;
-			else if( pos.x() > width()-rh_w )
+			} else if( pos.x() > width() - RESIZE_HANDLE_WIDTH) {
 				m = BottomRight;
-			else m = Bottom;
-		}
-		else
+			} else {
+				m = Bottom;
+			}
+		} else {
 			m = Client::mousePosition(pos);
-	}
-	else
+		}
+	} else {
 		m = Client::mousePosition(pos);
+	}
 	return m;
 }
 
@@ -532,47 +474,34 @@ void GlowClient::createButtons()
 	int s = isTool() ? SMALL_BITMAP_SIZE : DEFAULT_BITMAP_SIZE;
 	QSize size(s,s);
 
-	m_stickyButton = factory->createGlowButton(
-		this, "StickyButton", i18n("Sticky"));
+	m_stickyButton = factory->createGlowButton(this, "StickyButton", i18n("Sticky"));
 	m_stickyButton->setFixedSize(size);
-	QObject::connect(m_stickyButton, SIGNAL(clicked()),
-		this, SLOT(toggleSticky()));
+	connect(m_stickyButton, SIGNAL(clicked()), this, SLOT(toggleSticky()));
 	m_buttonList.insert(m_buttonList.end(), m_stickyButton);
 
-	m_helpButton = factory->createGlowButton(
-		this, "HelpButton", i18n("Help"));
+	m_helpButton = factory->createGlowButton(this, "HelpButton", i18n("Help"));
 	m_helpButton->setFixedSize(size);
-	QObject::connect(m_helpButton, SIGNAL(clicked()),
-		this, SLOT(contextHelp()));
+	connect(m_helpButton, SIGNAL(clicked()), this, SLOT(contextHelp()));
 	m_buttonList.insert(m_buttonList.end(), m_helpButton);
 
-	m_minimizeButton = factory->createGlowButton(
-		this, "IconifyButton", i18n("Minimize"));
+	m_minimizeButton = factory->createGlowButton(this, "IconifyButton", i18n("Minimize"));
 	m_minimizeButton->setFixedSize(size);
-	QObject::connect(m_minimizeButton, SIGNAL(clicked()),
-		this, SLOT(iconify()));
+	connect(m_minimizeButton, SIGNAL(clicked()), this, SLOT(iconify()));
 	m_buttonList.insert(m_buttonList.end(), m_minimizeButton);
 
-	m_maximizeButton=factory->createGlowButton(
-		this, "MaximizeButton", i18n("Maximize"));
+	m_maximizeButton=factory->createGlowButton(this, "MaximizeButton", i18n("Maximize"));
 	m_maximizeButton->setFixedSize(size);
-	QObject::connect(m_maximizeButton, SIGNAL(clicked(int)),
-		this, SLOT(slotMaximize(int)));
+	connect(m_maximizeButton, SIGNAL(clicked(int)), this, SLOT(slotMaximize(int)));
 	m_buttonList.insert(m_buttonList.end(), m_maximizeButton);
 
-	m_closeButton = factory->createGlowButton(
-		this, "CloseButton", i18n("Close"));
+	m_closeButton = factory->createGlowButton(this, "CloseButton", i18n("Close"));
 	m_closeButton->setFixedSize(size);
-	QObject::connect(m_closeButton, SIGNAL(clicked()),
-		this, SLOT(closeWindow()));
+	connect(m_closeButton, SIGNAL(clicked()), this, SLOT(closeWindow()));
 	m_buttonList.insert(m_buttonList.end(), m_closeButton);
 }
 
 void GlowClient::resetLayout()
 {
-	const unsigned int sideMargin = SIDE_MARGIN;
-	const unsigned int bottomMargin = BOTTOM_MARGIN;
-
 	if( m_mainLayout )
 		delete m_mainLayout;
 	m_mainLayout = new QVBoxLayout(this, 0, 0);
@@ -581,37 +510,38 @@ void GlowClient::resetLayout()
 	updateButtonPositions();
 	updateButtonPixmaps();
 
-	QHBoxLayout *topLayout = new QHBoxLayout(m_mainLayout);
+	QBoxLayout *topLayout = new QBoxLayout(m_mainLayout, QBoxLayout::LeftToRight, 0, 0);
 	topLayout->setMargin(0);
 	topLayout->setSpacing(TITLE_SPACING);
-	topLayout->addSpacing(sideMargin);
+	topLayout->addSpacing(SIDE_MARGIN);
 	QVBoxLayout *outerLeftLayout = new QVBoxLayout(topLayout);
 	outerLeftLayout->addSpacing(TITLE_MARGIN);
 	outerLeftLayout->addItem(m_leftButtonLayout);
 	outerLeftLayout->addSpacing(1);
-	topLayout->addSpacing(sideMargin);
+	topLayout->addSpacing(SIDE_MARGIN);
 
 	m_titleSpacer = new QSpacerItem(0, 0,
 		QSizePolicy::Expanding, QSizePolicy::Expanding);
 	topLayout->addItem(m_titleSpacer);
 
-	topLayout->addSpacing(sideMargin);
+	topLayout->addSpacing(SIDE_MARGIN);
 	QVBoxLayout *outerRightLayout = new QVBoxLayout(topLayout);
 	outerRightLayout->addSpacing(TITLE_MARGIN);
 	outerRightLayout->addItem(m_rightButtonLayout);
 	outerRightLayout->addSpacing(1);
-	topLayout->addSpacing(sideMargin);
+	topLayout->addSpacing(SIDE_MARGIN);
 
-	QHBoxLayout *midLayout = new QHBoxLayout(m_mainLayout, 0);
-	midLayout->addSpacing(sideMargin);
+	QBoxLayout *midLayout = new QBoxLayout(m_mainLayout, QBoxLayout::LeftToRight, 0, 0);
+	midLayout->addSpacing(SIDE_MARGIN);
 	midLayout->addWidget(windowWrapper());
-	midLayout->addSpacing(sideMargin);
+	midLayout->addSpacing(SIDE_MARGIN);
 
 	if( GlowClientGlobals::instance()->config->showResizeHandle
-		&& !isTool() && isResizable() )
+		&& !isTool() && isResizable() ) {
 		m_mainLayout->addSpacing(RESIZE_HANDLE_HEIGHT);
-	else
-		m_mainLayout->addSpacing(bottomMargin);
+	} else {
+		m_mainLayout->addSpacing(BOTTOM_MARGIN);
+	}
 	m_mainLayout->setStretchFactor(topLayout, 0);
 	m_mainLayout->setStretchFactor(midLayout, 1);
 }
@@ -632,12 +562,12 @@ void GlowClient::updateButtonPositions()
 	// reset left and right button layout
 	if(m_leftButtonLayout)
 		delete m_leftButtonLayout;
-	m_leftButtonLayout = new QHBoxLayout();
+	m_leftButtonLayout = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
 	m_leftButtonLayout->setMargin(0);
 	m_leftButtonLayout->setSpacing(TITLE_SPACING);
 	if(m_rightButtonLayout)
 		delete m_rightButtonLayout;
-	m_rightButtonLayout = new QHBoxLayout();
+	m_rightButtonLayout = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
 	m_rightButtonLayout->setMargin(0);
 	m_rightButtonLayout->setSpacing(TITLE_SPACING);
 
@@ -653,7 +583,7 @@ void GlowClient::updateButtonPositions()
 			button = m_minimizeButton;
 		else if( c=='A' && isMaximizable() ) // maximize
 			button = m_maximizeButton;
-		else if( c=='X' ) // close
+		else if( c=='X' && isCloseable() ) // close
 			button= m_closeButton;
 		else if( c=='_' ) // spacer item
 		{
@@ -665,16 +595,12 @@ void GlowClient::updateButtonPositions()
 		else if( c=='|' )
 			leftButtons = false;
 
-		if(button)
-		{
+		if (button) {
 			button->show(); // show visible buttons
-			if(leftButtons)
-			{
+			if (leftButtons) {
 				m_leftButtonList.insert(m_leftButtonList.end(), button);
 				m_leftButtonLayout->addWidget(button);
-			}
-			else
-			{
+			} else {
 				m_rightButtonList.insert(m_rightButtonList.end(), button);
 				m_rightButtonLayout->addWidget(button);
 			}
@@ -686,15 +612,15 @@ void GlowClient::updateButtonPixmaps()
 {
 	GlowClientGlobals *globals = GlowClientGlobals::instance();
 
-	if( isSticky() )
+	if ( isSticky() ) {
 		m_stickyButton->setPixmapName(globals->getPixmapName(
 			GlowClientGlobals::StickyOn, isActive(),
 			isLeft(m_stickyButton), isTool()));
-	else
+	} else {
 		m_stickyButton->setPixmapName(globals->getPixmapName(
 			GlowClientGlobals::StickyOff, isActive(),
 			isLeft(m_stickyButton), isTool()));
-
+	}
 	m_helpButton->setPixmapName(globals->getPixmapName(
 		GlowClientGlobals::Help, isActive(),
 		isLeft(m_helpButton), isTool()));
@@ -703,15 +629,15 @@ void GlowClient::updateButtonPixmaps()
 		GlowClientGlobals::Iconify, isActive(),
 		isLeft(m_minimizeButton), isTool()));
 
-	if( isMaximized() )
+	if ( isMaximized() ) {
 		m_maximizeButton->setPixmapName(globals->getPixmapName(
 			GlowClientGlobals::MaximizeOn, isActive(),
 			isLeft(m_maximizeButton), isTool()));
-	else
+	} else {
 		m_maximizeButton->setPixmapName(globals->getPixmapName(
 			GlowClientGlobals::MaximizeOff, isActive(),
 			isLeft(m_maximizeButton), isTool()));
-
+	}
 	m_closeButton->setPixmapName(globals->getPixmapName(
 		GlowClientGlobals::Close, isActive(),
 		isLeft(m_closeButton), isTool()));
@@ -719,8 +645,6 @@ void GlowClient::updateButtonPixmaps()
 
 void GlowClient::doShape()
 {
-	QRect r_title = m_titleSpacer->geometry();
-
 	QRegion mask(rect());
 	// edges
 
@@ -756,27 +680,29 @@ void GlowClient::slotMaximize(int button)
 		maximize(MaximizeFull);
 }
 
+};
+
 extern "C"
 {
 	Client * allocate(Workspace * ws, WId w)
 	{
-		return new GlowClient(ws, w);
+		return new Glow::GlowClient(ws, w);
 	}
 
 	void init()
 	{
-		GlowClientGlobals::instance();
+		Glow::GlowClientGlobals::instance();
 	}
 
 	void reset()
 	{
-		GlowClientGlobals::instance()->reset();
+		Glow::GlowClientGlobals::instance()->reset();
 		Workspace::self()->slotResetAllClientsDelayed();
 	}
 
 	void deinit()
 	{
-		delete GlowClientGlobals::instance();
+		delete Glow::GlowClientGlobals::instance();
 	}
 }
 
