@@ -19,6 +19,7 @@
   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
+#include "config.h"
 #include <unistd.h> // for usleep
 #include <math.h>
 
@@ -41,15 +42,11 @@
 
 using namespace KWinInternal;
 
-const uint openLookCornerSize = 11;
-const uint openLookMargin = 5;
-const uint openLookTextVMargin = 1;
-
 extern "C"
 {
   Client * allocate(Workspace * ws, WId w, int tool)
   {
-    return new OpenLook(ws, w, tool != 0);
+    return new OpenLook::OpenLook(ws, w, tool != 0);
   }
 
   void init()
@@ -69,6 +66,13 @@ extern "C"
   }
 }
 
+
+namespace OpenLook {
+
+const uint openLookCornerSize = 11;
+const uint openLookMargin = 5;
+const uint openLookTextVMargin = 1;
+
 OpenLook::OpenLook
 (
  Workspace    * ws,
@@ -197,14 +201,17 @@ OpenLook::doLayout()
 
   layout->addSpacing(2);
 
-  QHBoxLayout * midLayout   = new QHBoxLayout(layout, 0, 0);
+  QBoxLayout * midLayout   = new QBoxLayout(layout, QBoxLayout::LeftToRight, 0, 0);
  
   midLayout->addWidget(windowWrapper(), 1);
 }
 
   void
-OpenLook::animateIconifyOrDeiconify(bool iconify)
+OpenLook::animateIconifyOrDeiconify(bool /*iconify*/)
 {
+  if (!options->animateMinimize)
+    return;
+  
   NETRect r = netWinInfo()->iconGeometry();
 
   QRect icongeom(r.pos.x, r.pos.y, r.size.width, r.size.height);
@@ -586,5 +593,7 @@ OpenLook::mouseReleaseEvent(QMouseEvent * e)
   Client::mouseReleaseEvent(e);
 }
 
+};
+
 #include "OpenLook.moc"
 // vim:ts=2:sw=2:tw=78:set et:
