@@ -95,11 +95,11 @@ void dotNETstyle::polish(QWidget* widget)
 // we can't simply set a palette -- upon color-theme changes, we have
 // to update the palette again.
 	bool extraPalette = false;
-        
+
 	if (widget->inherits("QComboBox")) {
 		widget->installEventFilter (this);
 		updatePalette( (QComboBox*) widget );
-		extraPalette = true;                
+		extraPalette = true;
 	} else {
 		winstyle->polish(widget);
 	}
@@ -118,7 +118,7 @@ void dotNETstyle::polish(QWidget* widget)
 void dotNETstyle::unPolish(QWidget* widget)
 {
 	winstyle->unPolish(widget);
-	
+
 	if (widget->inherits("QComboBox")) {
 		widget->removeEventFilter (this);
 	}
@@ -127,8 +127,13 @@ void dotNETstyle::unPolish(QWidget* widget)
 void dotNETstyle::renderMenuBlendPixmap( KPixmap &pix, const QColorGroup &cg, const QPopupMenu *popup ) const
 {
 	QPainter p( &pix );
-	p.fillRect( 0, 0, pix.width(), pix.height(), cg.background().light() );
-	p.fillRect( popup->frameRect().left() + 1, 0, 22, pix.height(), cg.mid() );
+	if (QApplication::reverseLayout()) {
+		p.fillRect( popup->frameRect().width()-22, 0, 22, pix.height(), cg.mid() );
+		p.fillRect( 0, 0, popup->frameRect().width()-22, pix.height(), cg.background().light() );
+	} else {
+		p.fillRect( 0, 0, pix.width(), pix.height(), cg.background().light() );
+		p.fillRect( popup->frameRect().left() + 1, 0, 22, pix.height(), cg.mid() );
+	}
 }
 
 void dotNETstyle::renderButton(QPainter *p,
@@ -449,12 +454,12 @@ void dotNETstyle::drawControl(ControlElement element,
 			int x, y, w, h;
 			r.rect(&x, &y, &w, &h);
 
-			switch (tbs) 
+			switch (tbs)
 			{
 				case QTabBar::RoundedAbove: {
 					p->setPen(cg.background().dark());
 					p->drawLine(x + w - 1, y, x + w - 1, y + h - 2);
-	
+
 					p->setPen(cg.background().light());
 					p->drawLine(x, y, x + w - 1, y);
 					p->drawLine(x, y, x, y + h - 1);
@@ -467,7 +472,7 @@ void dotNETstyle::drawControl(ControlElement element,
 				}
 
 				case QTabBar::RoundedBelow: {
-					p->setPen(cg.background().light());					
+					p->setPen(cg.background().light());
 					p->drawLine(x, y, x, y + h - 1);
 
 					p->setPen(cg.background().dark());
@@ -498,22 +503,20 @@ void dotNETstyle::drawControl(ControlElement element,
 	//	-----------------------------------------
 		case CE_MenuBarItem: {
 			QMenuItem *mi = opt.menuItem();
-
 			bool active  = flags & Style_Active;
 			bool focused = flags & Style_HasFocus;
 
 			if ( active && focused ) {
-				p->setPen(cg.highlight().dark());
-				p->setBrush(cg.highlight());
 				const int text_flags =
-					AlignVCenter | ShowPrefix | DontClip | SingleLine;
-				QRect mitr;
-				p->drawText(mitr, text_flags, mi->text(), -1, &mitr);
-				
-				p->drawRect(r);
-				mitr.moveCenter(r.center());
+					AlignVCenter | AlignHCenter | ShowPrefix | DontClip | SingleLine;
 				p->setPen(cg.highlightedText());
-				p->drawText(mitr, text_flags, mi->text());
+				p->setBrush(cg.highlight());
+				p->setPen(cg.highlight().dark());
+				p->drawRect(r);
+
+				p->setPen(cg.highlightedText());
+				p->drawText(r, text_flags, mi->text());
+
 			} else {
 				winstyle->drawControl(element, p, widget, r, cg, flags, opt);
 			}
@@ -532,7 +535,6 @@ void dotNETstyle::drawControl(ControlElement element,
 			const int tab = opt.tabWidth();
 
 			int checkcol = QMAX(opt.maxIconWidth(), 26);
-
 			p->save();
 			int x, y, w, h;
 			r.rect(&x, &y, &w, &h);
@@ -554,12 +556,19 @@ void dotNETstyle::drawControl(ControlElement element,
 				p->drawPixmap( x, y, *pum->erasePixmap(), x, y, w, h );
 			} else {
 				p->fillRect( r, cg.background().light() );
-				p->fillRect( x, y, 22, h, cg.mid() );
+				if (!QApplication::reverseLayout())
+					p->fillRect( x, y, 22, h, cg.mid() );
+				else // i wonder why exactly +1 (diego)
+					p->fillRect( w-22, y, 22+1, h, cg.mid() );
 			}
 
 			if (mi->isSeparator()) {
 				p->setPen(cg.mid());
-				p->drawLine(x + opt.maxIconWidth() + 6, y, x + w, y);
+				if (!QApplication::reverseLayout())
+					p->drawLine(x + opt.maxIconWidth() + 6, y, x + w, y);
+				else
+					p->drawLine(w - (x + opt.maxIconWidth() + 6), y,
+					            x, y);
 				return;
 			}
 
@@ -581,6 +590,10 @@ void dotNETstyle::drawControl(ControlElement element,
 				QRect cr(xpos, y, opt.maxIconWidth(), h);
 				QRect pmr(0, 0, pixw, pixh);
 				pmr.moveCenter(cr.center());
+
+				if ( QApplication::reverseLayout() )
+					pmr = visualRect( pmr, r );
+
 				p->setPen(cg.highlightedText());
 				p->drawPixmap(pmr.topLeft(), pixmap);
 				p->restore();
@@ -589,20 +602,23 @@ void dotNETstyle::drawControl(ControlElement element,
 					int xp = xpos;
 
 					SFlags cflags = Style_Default;
-					if (!disabled) {
+					if (!disabled)
 						cflags |= Style_Enabled;
-					} else {
+					else
 						cflags |= Style_On;
-					}
 
-					if (active) {
+					if (active)
 						p->setPen(cg.highlightedText());
-					} else {
+					else
 						p->setPen(cg.buttonText());
-					}
+
+		
+					QRect rr = QRect( xp, y, 22, h );
+					if ( QApplication::reverseLayout() )
+						rr = visualRect( rr, r );
 
 					drawPrimitive(PE_CheckMark, p,
-					              QRect(xp, y, 22, h),
+					              rr,
 					              cg, cflags);
 				}
 			}
@@ -615,16 +631,13 @@ void dotNETstyle::drawControl(ControlElement element,
 				int m = itemVMargin;
 				p->save();
 				/*
-				if (disabled && !active) {
+/				if (disabled && !active) {
 					p->setPen(cg.light());
 					mi->custom()->paint(p, cg, active, !disabled,
 					                    xpos+1, y+m+1, w-xm-tab+1, h-2*m);
-				}
-				*/
+				}*/
 				p->setPen(cg.text());
-
-				mi->custom()->paint(p, cg, active, !disabled,
-				                    x+xm, y+m, w-xm-tab+1, h-2*m);
+				mi->custom()->paint(p, cg, active, !disabled, x+xm, y+m, w-xm-tab+1, h-2*m);
 				p->restore();
 				return;
 			} else {
@@ -632,8 +645,8 @@ void dotNETstyle::drawControl(ControlElement element,
 				if(!s.isNull()) {
 					int t = s.find('\t');
 					int m = itemVMargin;
-	
-					const int text_flags =
+
+					int text_flags =
 						AlignVCenter | ShowPrefix | DontClip | SingleLine;
 
 					if (active && !disabled) {
@@ -647,11 +660,21 @@ void dotNETstyle::drawControl(ControlElement element,
 					if (t >= 0) {
 						int xp;
 						xp = x + w - tab - rightBorder - itemHMargin - itemFrame + 1;
-						p->drawText(xp, y+m, tab, h-2*m, text_flags, s.mid(t+1));
+
+						QRect rr = QRect( xp, y+m, tab, h-2*m );
+						if ( QApplication::reverseLayout() )
+							rr = visualRect( rr, r );
+
+						p->drawText(rr, text_flags, s.mid(t+1));
 						s = s.left(t);
 					}
-
-					p->drawText(xpos, y+m, w-xm-tab+1, h-2*m, text_flags, s);
+					
+					QRect rr = QRect( xpos, y+m, w-xm-tab+1, h-2*m );
+					if ( QApplication::reverseLayout() ){
+						rr = visualRect( rr, r );
+						text_flags |= AlignRight;
+					}
+					p->drawText(rr, text_flags, s);
 
 				} else if (mi->pixmap()) {
 					QPixmap *pixmap = mi->pixmap();
@@ -666,19 +689,21 @@ void dotNETstyle::drawControl(ControlElement element,
 			}
 
 			if (mi->popup()) {
-				int dim = (h - 2 * itemFrame) / 2;
+				int dim = pixelMetric(PM_MenuButtonIndicator);
 
-				xpos = x+w - arrowHMargin - itemFrame - dim;
+				xpos = x+w - arrowHMargin - 2*itemFrame - dim;
 
-				if (active && !disabled) {
+				if (active && !disabled)
 					p->setPen(cg.highlightedText());
-				} else {
+				else
 					p->setPen(cg.text());
-				}
 
-				drawPrimitive(PE_ArrowRight, p,
-				              QRect(xpos, y + h / 4, dim, dim),
-				                    cg, Style_Enabled);
+
+				QRect rr = QRect(xpos, y + h/2 - dim/2, dim, dim);
+				if ( QApplication::reverseLayout() )
+					rr = visualRect( rr, r );
+				drawPrimitive((QApplication::reverseLayout() ? PE_ArrowLeft : PE_ArrowRight),
+					      p, rr, cg, Style_Enabled);
 			}
 
 			p->restore();
@@ -690,7 +715,7 @@ void dotNETstyle::drawControl(ControlElement element,
 			const int markH = markW;
 			int posX = r.x() + ( r.width() - markW )/2 + 1;
 			int posY = r.y() + ( r.height() - markH )/2;
-			
+
 		// Could do with some optimizing/caching...
 			QPointArray a( markH*2 );
 			int i, xx, yy;
@@ -788,9 +813,15 @@ void dotNETstyle::drawComplexControl(ComplexControl control,
 				p->setBrush(cg.midlight());
 			}
 
-			p->drawRect(w - handle_offset - 1, y+1, handle_width + 2, h - 1);
+			QRect rr = QRect( w - handle_offset - 1, y+1, handle_width + 2, h - 1 );
+			if (QApplication::reverseLayout())
+				rr = visualRect( rr, r );
+			p->drawRect(rr);
 			p->setBrush(NoBrush);
-			p->drawRect(x+1, y+1, w-1, h-1);
+			rr = QRect( x+1, y+1, w-1, h-1 );
+			if (QApplication::reverseLayout())
+				rr = visualRect( rr, r );
+			p->drawRect( rr );
 
 			if (active)
 			        p->setPen(cg.highlightedText());
@@ -800,6 +831,8 @@ void dotNETstyle::drawComplexControl(ComplexControl control,
 			QRect cr(w - handle_offset, y + 2, handle_width, h - 4);
 			QRect pmr(0, 0, 7, 4);
 			pmr.moveCenter(cr.center());
+			if (QApplication::reverseLayout())
+				pmr = visualRect( pmr, r );
 			p->drawPixmap(pmr.topLeft(), downArrow);
 			p->restore();
 			break;
@@ -947,12 +980,17 @@ int dotNETstyle::pixelMetric(PixelMetric m, const QWidget *widget) const
 	// ------------
 		case PM_ProgressBarChunkWidth:
 			return 9;
-	
+
 	// SLIDER
 	// ------
 		case PM_SliderLength:
 			return 11;
-		
+
+	// MENU INDICATOR	
+	// --------------
+		case PM_MenuButtonIndicator:
+			return 8;
+
 	// CHECKBOXES / RADIO BUTTONS
 	// --------------------------
 		case PM_ExclusiveIndicatorWidth:    // Radiobutton size
@@ -979,29 +1017,31 @@ QSize dotNETstyle::sizeFromContents(ContentsType t,
 		case CT_PopupMenuItem: {
 		//	const QPopupMenu *popup = (const QPopupMenu *)widget;
 			QMenuItem *mi = opt.menuItem();
-			if (!widget || opt.isDefault()) {
+			if (!widget || opt.isDefault())
 				break;
-			}
 
 			int w = s.width(), h = s.height();
 
 			if (mi->custom()) {
 				w = mi->custom()->sizeHint().width();
 				h = mi->custom()->sizeHint().height();
-			} else if (mi->widget()) {
-			} else if (mi->isSeparator()) {
+			}
+			else if (mi->widget()) {
+				// don't change the size in this case.
+			}
+			else if (mi->isSeparator()) {
 				w = 10;
 				h = 1;
-			} else {
+			} else
 				return winstyle->sizeFromContents(t, widget, s, opt);
-			}
+
 			return QSize(w, h);
 		}
 
-		default: {
-			return winstyle->sizeFromContents(t, widget, s, opt);
-		}
+		default: 
+			;	// fall though
 	}
+	return winstyle->sizeFromContents(t, widget, s, opt);
 }
 
 void dotNETstyle::paletteChanged()
